(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.EorzeaTime = factory());
}(this, function () { 'use strict';

  var repeat = String.prototype.repeat || function repeat() {
    var count = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

    /* eslint-disable no-invalid-this */
    var string = String(this);
    var n = +count;
    var result = '';
    while (n--) {
      result += string;
    }
    return result;
  };

  var padStart = String.prototype.padStart || function padStart(maxLength) {
    var fillString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ' ';

    /* eslint-disable no-invalid-this */
    var string = String(this);
    var stringLength = string.length;
    if (maxLength <= stringLength) {
      return string;
    }
    var fillStringLength = String(fillString).length;
    var fillLength = maxLength - stringLength;
    var filler = repeat.call(fillString, Math.ceil(fillLength / fillStringLength));
    return filler + string;
  };

  var asyncGenerator = function () {
    function AwaitValue(value) {
      this.value = value;
    }

    function AsyncGenerator(gen) {
      var front, back;

      function send(key, arg) {
        return new Promise(function (resolve, reject) {
          var request = {
            key: key,
            arg: arg,
            resolve: resolve,
            reject: reject,
            next: null
          };

          if (back) {
            back = back.next = request;
          } else {
            front = back = request;
            resume(key, arg);
          }
        });
      }

      function resume(key, arg) {
        try {
          var result = gen[key](arg);
          var value = result.value;

          if (value instanceof AwaitValue) {
            Promise.resolve(value.value).then(function (arg) {
              resume("next", arg);
            }, function (arg) {
              resume("throw", arg);
            });
          } else {
            settle(result.done ? "return" : "normal", result.value);
          }
        } catch (err) {
          settle("throw", err);
        }
      }

      function settle(type, value) {
        switch (type) {
          case "return":
            front.resolve({
              value: value,
              done: true
            });
            break;

          case "throw":
            front.reject(value);
            break;

          default:
            front.resolve({
              value: value,
              done: false
            });
            break;
        }

        front = front.next;

        if (front) {
          resume(front.key, front.arg);
        } else {
          back = null;
        }
      }

      this._invoke = send;

      if (typeof gen.return !== "function") {
        this.return = undefined;
      }
    }

    if (typeof Symbol === "function" && Symbol.asyncIterator) {
      AsyncGenerator.prototype[Symbol.asyncIterator] = function () {
        return this;
      };
    }

    AsyncGenerator.prototype.next = function (arg) {
      return this._invoke("next", arg);
    };

    AsyncGenerator.prototype.throw = function (arg) {
      return this._invoke("throw", arg);
    };

    AsyncGenerator.prototype.return = function (arg) {
      return this._invoke("return", arg);
    };

    return {
      wrap: function (fn) {
        return function () {
          return new AsyncGenerator(fn.apply(this, arguments));
        };
      },
      await: function (value) {
        return new AwaitValue(value);
      }
    };
  }();

  var classCallCheck = function (instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  };

  var createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  var privateDateProperty = typeof Symbol === 'function' ? Symbol('privateDateProperty') : '_privateDateProperty';

  function computeEorzeaDate(date) {
    var eorzeaTime = new Date();
    var unixTime = Math.floor(date.getTime() * 1440 / 70);
    eorzeaTime.setTime(unixTime);
    return eorzeaTime;
  }

  var EorzeaTime = function () {
    function EorzeaTime() {
      var date = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date();
      classCallCheck(this, EorzeaTime);

      this[privateDateProperty] = computeEorzeaDate(date);
    }

    createClass(EorzeaTime, [{
      key: 'getHours',
      value: function getHours() {
        return this[privateDateProperty].getUTCHours();
      }
    }, {
      key: 'getMinutes',
      value: function getMinutes() {
        return this[privateDateProperty].getUTCMinutes();
      }
    }, {
      key: 'getSeconds',
      value: function getSeconds() {
        return this[privateDateProperty].getUTCSeconds();
      }
    }, {
      key: 'toString',
      value: function toString() {
        return [padStart.call(this.getHours(), 2, 0), padStart.call(this.getMinutes(), 2, 0), padStart.call(this.getSeconds(), 2, 0)].join(':');
      }
    }, {
      key: 'toJSON',
      value: function toJSON() {
        return this.toString();
      }
    }]);
    return EorzeaTime;
  }();

  return EorzeaTime;

}));